@@ -44,10 +44,14 @@
 //
 #define OIIO_VERSION_MAJOR 2
 #define OIIO_VERSION_MINOR 5
-#define OIIO_VERSION_PATCH 7
-#define OIIO_VERSION_TWEAK 0
+#define OIIO_VERSION_PATCH 10
+#define OIIO_VERSION_TWEAK 1
 #define OIIO_VERSION_RELEASE_TYPE 
 
+// Preprocessor utility: stringize
+#define OIIO_STRINGIZE_HELPER(a) #a
+#define OIIO_STRINGIZE(a) OIIO_STRINGIZE_HELPER(a)
+
 // Construct a single integer version number from major, minor, patch.
 // Example of its use:
 //
